#
# spec file for package libibverbs
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#%%define extraver -rc1
#%%define gitver -gite9f49fb

Name:           libibverbs
Summary:        Infiniband verbs library
License:        GPL-2.0 or BSD-2-Clause
Group:          System/Libraries
Version:        1.2.0
Release:        2.2
Source0:        %{name}-%{version}.tar.gz
Source1:        ibdev2netdev
Source2:        baselibs.conf
Source3:        neigh.h
#
Provides:       libusnic_verbs = %{version}
Obsoletes:      libusnic_verbs < %{version}
#
Patch1:         libibverbs-fix_aliasing.patch
Patch2:         libibverbs-1.1.4-fix-deleted-ntohl.patch
Patch10:        libibverbs-autotools.patch
Patch11:        libibverbs-s390.patch
Patch12:        libibverbs-aarch64.patch
#
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libnl3-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
Url:            http://www.openfabrics.org/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%define so_major 1
%define lname %{name}%{so_major}

%description
libibverbs is a library that allows userspace processes to use
InfiniBand "verbs" as described in the InfiniBand Architecture
Specification.	This includes direct hardware access for fast path
operations.

%package     -n %{lname}
Summary:        Infiniband verbs library
Group:          System/Libraries

%description -n %{lname}
libibverbs is a library that allows userspace processes to use
InfiniBand "verbs" as described in the InfiniBand Architecture
Specification.	This includes direct hardware access for fast path
operations.

This package contains the runtime library.

%package        runtime
Summary:        Tools for the Infiniband Verbs library and manpages
Group:          Productivity/Networking/System

%description    runtime
This package contains the Infiniband verbs tools and their man pages.

%package        devel
Summary:        Development files for the libibverbs library
Group:          Development/Libraries/C and C++
Requires:       %{name}-runtime = %{version}

%description    devel
Static libraries and header files for the Infiniband verbs library.

%package        devel-static
Summary:        Static libibverbs library
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version} glibc-devel

%description    devel-static
This package contains the static variant of libibverbs.

%prep
%setup -q -n %{name}-%{version}
%patch1
%patch2 -p1
%patch10
%patch11
%patch12 -p1
cp %{S:3} src/

%build
autoreconf -fi
%configure --disable-silent-rules
make %{?_smp_mflags}

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%install
make DESTDIR=%{buildroot} install
mkdir -p %{buildroot}/%_sysconfdir/libibverbs.d
install -m 755 %{S:1} %{buildroot}%{_bindir}

%files runtime
%defattr(-, root, root)
%doc COPYING ChangeLog
%_sysconfdir/libibverbs.d
%_bindir/*
%_mandir/man1/*

%files -n %{lname}
%defattr(-, root, root)
%_libdir/libibverbs.so.*

%files devel
%defattr(-,root,root)
%_includedir/infiniband
%_libdir/libibverbs.so
%_mandir/man3/*

%files devel-static
%defattr(-,root,root)
%_libdir/libibverbs.a
%_libdir/libibverbs.la

%changelog
* Thu Aug  4 2016 pth@suse.de
  Update to 1.2.0 (bsc#966196).
  Changes since rc1:
  * libibverbs.spec.in: Use config.h substitution.
  * Makefile.am: Don't allow strict aliasing by default
  * Makefile.am: Fix "make distcheck"
* Tue Apr 19 2016 pth@suse.de
- Add libibverbs-aarch64.patch to add macro definitions for memory
  barriers.
* Mon Feb 29 2016 pth@suse.de
- Add provides/obsoletes for libusnic_verbs (fate#319923)
* Mon Feb 15 2016 pth@suse.de
- Update to git version 1.2.0-rc1 (fate#318620)
  For detailed changes see the included ChangeLog.
- Patches removed as the changes have been integrated upstream:
    libibverbs-add-s390x-platform-support.patch
    libibverbs-Add-ibv_port_cap_flags.patch
    libibverbs-Use-neighbour-lookup-for-RoCE-UD-QPs-Eth-L2-resoluti.patch
    libibverbs-Add-ibv_query_port_ex-support.patch
    libibverbs-Add-receive-flow-steering-support.patch
- Add neigh.h from the RWTH repo.
- Add libibverbs-s390.patch so that builds for s390 don't fail.
* Tue Aug 11 2015 pth@suse.de
- Replace libibverbs-s390.patch with
  libibverbs-add-s390x-platform-support.patch as the implementation
  changed (bsc#934683).
- Tag baselibs.conf as Source
* Fri Aug 29 2014 pth@suse.de
- Remove the s390 patch.
- Adapt libibverbs-Add-receive-flow-steering-support.patch to the
  changed sources.
* Thu Aug 21 2014 pth@suse.de
- Readd the missing s390 patch.
* Tue Jun  3 2014 pth@suse.de
- Update to OFED 3.12 final.
* Thu Apr 10 2014 stefan.fent@suse.com
- removed unneeded patches for new version:
    libibverbs-Infrastructure_to_support_verbs_extensions.patch
    libibverbs-XRC_man_pages.patch
    libibverbs-Add_support_for_XRC_SRQs.patch
    libibverbs-Introduce_XRC_domains_XRCDs.patch
    libibverbs-Use-IBV_SEND_INLINE-in-example-pingpong-programs.patch
    libibverbs-Add_ibv_open_qp_for_XRC_receive_QPs.patch
    libibverbs-Add_support_for_XRC_QPs.patch
    libibverbs-Add_XRC_sample_application.patch
    libibverbs-Add-general-definitions-to-support-uverbs-extensions.patch
    libibverbs-Fix_XRC_sample_application_ibv_xsrq_pingpong_issues.patch
* Thu Apr  3 2014 pth@suse.de
- Fix underquoting and change AC_HELP_MESSAGE to AS_HELP_MESSAGE
  in libibverbs-Use-neighbour-lookup-for-RoCE-UD-QPs-Eth-L2-resoluti.patch
- Add libibverbs-autotools.patch that correctly quotes another
  AS_HELP_MESSGE call and a use of AC_MSG_ERROR.
* Mon Mar 31 2014 pth@suse.de
- Add patches from Mellanox (bnc#871161):
  * libibverbs-Add-ibv_port_cap_flags.patch
    Add ibv_port_cap_flag
  * libibverbs-Use-neighbour-lookup-for-RoCE-UD-QPs-Eth-L2-resoluti.patch
    Use neighbour lookup for RoCE UD QPs Eth L2 resolution.
  * libibverbs-Add-ibv_query_port_ex-support.patch
    Add extended support for ibv_query_port.
  * libibverbs-Add-receive-flow-steering-support.patch
    Add support to steer receiving flows.
* Mon Mar 31 2014 pth@suse.de
- Fix libibverbs-s390.patch to not make header unusable.
* Fri Mar 28 2014 pth@suse.de
- Fix spec file to get ibdev2netdev installed in the rigth place.
- Adapt libibverbs-s390.patch to changed sources.
* Thu Mar 27 2014 pth@suse.de
- On request from Mellanox add the ibdev2netdev script from
  the compat-rdma package in OFED. This script shows which IB
  device is attached to which network device (bnc#870419).
* Thu Mar 20 2014 ro@suse.de
- fix arch.h to be usable on s390 additional to s390x
* Tue Feb 11 2014 pth@suse.de
- Add and adapt patches from Mellanox that add XRC support
  (bnc#858729):
  libibverbs-Add_ibv_open_qp_for_XRC_receive_QPs.patch
  libibverbs-Add_support_for_XRC_QPs.patch
  libibverbs-Add_support_for_XRC_SRQs.patch
  libibverbs-Add_XRC_sample_application.patch
  libibverbs-Fix_XRC_sample_application_ibv_xsrq_pingpong_issues.patch
  libibverbs-Infrastructure_to_support_verbs_extensions.patch
  libibverbs-Introduce_XRC_domains_XRCDs.patch
  libibverbs-Use-IBV_SEND_INLINE-in-example-pingpong-programs.patch
  libibverbs-XRC_man_pages.patch
* Tue Feb 11 2014 pth@suse.de
- Fix source URI.
* Mon Feb 10 2014 pth@suse.de
- Fix baselibs.conf.
* Mon Feb  3 2014 pth@suse.de
- Readd baselibs.conf.
* Thu Jan 30 2014 pth@suse.de
- License is GPL-2.0 or BSD-2-Clause
- Add COPYING to package documentation.
* Fri Jan 17 2014 pth@suse.de
- Update to 1.1.7 from OFED 3.12
- Add libibverbs-s390.patch for s390 support.
* Mon Aug 12 2013 kleinrob@mpip-mainz.mpg.de
- Re-added accidentlly removed ntohl() in examples/pingping.c.
* Tue Sep 18 2012 pth@suse.de
- Simplify spec file a bit by using a define for the library name.
* Fri Aug 31 2012 pth@suse.de
- update to 1.1.4-1.24.gb89d4d7 from OFED 1.5.4.1.
- Rename configure.patch to libibverbs-no_silent_rules.patch.
- Pass V=1 to make in case silent rules were added.
* Sun Aug 26 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Kill configure.patch: absence of AM_SILENT_RULES is no problem
- Redo libibverbs-fix_aliasing.patch with proper approach
- Parallel build with %%_smp_mflags
* Thu Jun 28 2012 pth@suse.de
- Fix aliasing issue in example program.
* Tue May  8 2012 pth@suse.de
- BuildRequire automake, autoconf and libtool.
* Wed Dec 15 2010 pth@suse.de
- Add a runtime package with tools and their man pages.
- Split off the dynamic library into its own versioned sub package.
- Split off the static library into its own sub package.
- Clean up the spec file.
* Thu Oct 21 2010 stefan.fent@novell.com
- update to v1.1.4-0.14.gb6c138b for OFED 1.5.2
* Sun May 23 2010 jjolly@novell.com
- Same tarball, different name.  Leaving the postfix
  - 0.6.g932f1a2 on the tarball to identify it for future updates
* Sun May 23 2010 jjolly@novell.com
- Updated to v1.1.3 from OFED 1.5.1
* Sat Jul 11 2009 jjolly@suse.de
- Updated to v1.1.2 from OFED 1.4.1 release
* Wed Oct 15 2008 jjolly@suse.de
- Updated to release from OFED 1.3.1
* Thu Feb 28 2008 jjolly@suse.de
- Updated to release from OFED 1.3 GA
- Added man7 to devel files list
* Tue Jan 29 2008 jjolly@suse.de
- Updated to release from OFED 1.3 rc2
* Wed Jun 20 2007 hvogel@suse.de
- Initial Package, Version 1.1.1
